@@ -1,8 +1,9 @@
-from paramga.encoding import decode_parameters, encode_parameters
 import random
 
+from paramga.encoding import decode_parameters, encode_parameters
 
-def combine_param_state(param_a, param_b):
+
+def param_crossover(param_a, param_b):
     encoded_param_a = encode_parameters(param_a)
     encoded_param_b = encode_parameters(param_b)
     number_of_params = len(encoded_param_a)
