@@ -15,7 +15,7 @@ class TestMutateParamState:
             "foo": {
                 "type": "number",
                 "min": 3,
-                "max": 8,
+                "max": 14,
                 "step": 1,
             }
         }
@@ -28,3 +28,9 @@ class TestMutateParamState:
         input_state = self.demo_state()
         out_state = set_seed(1)(mutate_param_state)(input_state, self.demo_conf())
         assert out_state['foo'] == input_state['foo'] - 1
+
+    def test_is_limited_by_max(self):
+        input_state = self.demo_state()
+        input_state['foo'] = 99
+        out_state = set_seed(1)(mutate_param_state)(input_state, self.demo_conf())
+        assert out_state['foo'] == 14
